@@ -1,21 +1,26 @@
 `sd.multiperiod` <-
-function (x, na.rm=FALSE, periods = 12, ...)
+function (x, na.rm=TRUE, periods = 12, ...)
 {
-    x = checkData (x,na.rm=na.rm, ...=...)
-    #scale standard deviation by multiplying by the square root of the number of periods to scale by
-	return(sqrt(periods)*sd(x, na.rm=na.rm))
+    if (is.vector(x)) {
+        x = checkData (x,na.rm=na.rm, method="vector", ...=...)
+        #scale standard deviation by multiplying by the square root of the number of periods to scale by
+        sqrt(periods)*sd(x, na.rm=na.rm)
+    } else {
+        x = checkData (x,na.rm=na.rm, method="matrix", ...=...)
+        apply(x, 2, sd.multiperiod, na.rm = na.rm, periods=periods, ...=...)
+    }
 }
 
 `sd.annualized` <-
-function (x, na.rm=FALSE, periods = 12, ...)
-{
-	sd.multiperiod(x, na.rm=na.rm, periods = periods, ...=...)
+function (x, na.rm=TRUE, periods = 12, ...)
+{   # wrapper function for backwards compatibility
+    sd.multiperiod(x, na.rm=na.rm, periods = periods, ...=...)
 }
 
 `StdDev.annualized` <-
-function (Ra, na.rm=FALSE, scale = 12, ...)
+function (Ra, na.rm=TRUE, scale = 12, ...)
 {   # wrapper function for backwards compatibility
-	sd.multiperiod(Ra, na.rm=na.rm, periods = scale, ...=...)
+    sd.multiperiod(Ra, na.rm=na.rm, periods = scale, ...=...)
 }
 
 ###############################################################################
@@ -40,10 +45,24 @@ function(Ra) {
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: StdDev.annualized.R,v 1.8 2007/06/07 23:02:20 brian Exp $
+# $Id: StdDev.annualized.R,v 1.12 2007/08/26 10:01:46 brian Exp $
 #
 ###############################################################################
 # $Log: StdDev.annualized.R,v $
+# Revision 1.12  2007/08/26 10:01:46  brian
+# - code comment and indentation cleanup, no functional change
+#
+# Revision 1.11  2007/08/26 09:54:28  brian
+# - simplify recursion to eliminate possibility of endless loop
+#
+# Revision 1.10  2007/08/25 22:55:49  brian
+# - modify to mimic class behavior of sd function
+#   should handle both single and multicolumn data smoothly now
+#
+# Revision 1.9  2007/08/16 14:27:37  peter
+# - added NA removal default
+# - modified checkData to return a vector
+#
 # Revision 1.8  2007/06/07 23:02:20  brian
 # - update passing of ... into functions
 # - fix scale/periods cut and paste error
