@@ -24,7 +24,7 @@ function (R, p=.95, modified=FALSE, add=FALSE, periods = 1)
     columnnames=colnames(R)
     # FUNCTION:
     for(column in 1:columns) {
-        r = R[,column,drop=FALSE]
+        r = na.omit(R[,column,drop=FALSE])
         if (!is.numeric(r)) stop("The selected column is not numeric")
 
         VaR = VaR.CornishFisher(r, p=p, modified=modified)
@@ -49,9 +49,10 @@ function (R, p=.95, modified=FALSE, add=FALSE, periods = 1)
         # some backflips to name the single column zoo object
         result = as.numeric(result)
     }
-    else
+    else{
         colnames(result) = columnnames
-
+        rownames(result) = "Beyond VaR"
+    }
     # Return Value:
     result
 }
@@ -64,10 +65,14 @@ function (R, p=.95, modified=FALSE, add=FALSE, periods = 1)
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: VaR.Beyond.R,v 1.8 2007/06/24 14:05:38 brian Exp $
+# $Id: VaR.Beyond.R,v 1.9 2007/08/28 14:56:49 peter Exp $
 #
 ###############################################################################
 # $Log: VaR.Beyond.R,v $
+# Revision 1.9  2007/08/28 14:56:49  peter
+# - added na.omit to column processing
+# - added rowname when multiple columns are returned
+#
 # Revision 1.8  2007/06/24 14:05:38  brian
 # - add parameter 'add'
 #
