@@ -18,7 +18,7 @@ function (R, legend.loc = NULL, colorset = (1:12), ...)
     # Transform input data to a matrix
     x = checkDataMatrix(R)
 
-    chart.TimeSeries(x, type = "h", colorset = colorset, legend.loc = legend.loc, ...)
+    chart.TimeSeries(x, type = "h", colorset = colorset, legend.loc = legend.loc, lend="butt",...)
 
 }
 
@@ -30,10 +30,13 @@ function (R, legend.loc = NULL, colorset = (1:12), ...)
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Bar.R,v 1.2 2007/02/07 13:24:49 brian Exp $
+# $Id: chart.Bar.R,v 1.3 2007/11/18 14:28:02 peter Exp $
 #
 ###############################################################################
 # $Log: chart.Bar.R,v $
+# Revision 1.3  2007/11/18 14:28:02  peter
+# - squared off the bar ends
+#
 # Revision 1.2  2007/02/07 13:24:49  brian
 # - fix pervasive comment typo
 #
