@@ -24,9 +24,9 @@ function (Ra, Rb, width = 12, xaxis = TRUE, legend.loc = NULL, colorset = (1:12)
             column.calc = rollapply(na.omit(merged.assets[,,drop=FALSE]), width = width, FUN= function(x) cor(x[,1,drop=FALSE], x[,2,drop=FALSE]), by = 1, by.column = FALSE, na.pad = na.pad, align = "right")
 
             # some backflips to name the single column zoo object
-            column.calc = as.matrix(column.calc)
-            colnames(column.calc) = paste(columnnames.a[column.a], columnnames.b[column.b], sep = " to ")
-            column.calc = zoo(column.calc, order.by = rownames(column.calc))
+            column.calc.tmp = as.matrix(column.calc)
+            colnames(column.calc.tmp) = paste(columnnames.a[column.a], columnnames.b[column.b], sep = " to ")
+            column.calc = zoo(column.calc.tmp, order.by = time(column.calc))
 
             if(column.a == 1 & column.b == 1)
                 Result.calc = column.calc
@@ -47,10 +47,13 @@ function (Ra, Rb, width = 12, xaxis = TRUE, legend.loc = NULL, colorset = (1:12)
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.RollingCorrelation.R,v 1.5 2007/04/14 15:42:35 brian Exp $
+# $Id: chart.RollingCorrelation.R,v 1.6 2007/10/11 03:56:12 peter Exp $
 #
 ###############################################################################
 # $Log: chart.RollingCorrelation.R,v $
+# Revision 1.6  2007/10/11 03:56:12  peter
+# - fixed so that it will handle zoo objects with yearmon dates
+#
 # Revision 1.5  2007/04/14 15:42:35  brian
 # - standardize Ra as first argument for asset returns
 #
